@@ -2,7 +2,6 @@
 from __future__ import annotations
 
 import contextlib
-import fnmatch
 import importlib
 import json
 import logging
@@ -10,6 +9,7 @@ import os
 import re
 import shutil
 import subprocess
+import sys
 import tempfile
 import warnings
 from collections import OrderedDict
@@ -27,6 +27,7 @@ from ansible_compat.config import (
     parse_ansible_version,
 )
 from ansible_compat.constants import (
+    META_MAIN,
     MSG_INVALID_FQRL,
     RC_ANSIBLE_OPTIONS_ERROR,
     REQUIREMENT_LOCATIONS,
@@ -50,6 +51,7 @@ else:
 _logger = logging.getLogger(__name__)
 # regex to extract the first version from a collection range specifier
 version_re = re.compile(":[>=<]*([^,]*)")
+namespace_re = re.compile("^[a-z][a-z0-9_]+$")
 
 
 class AnsibleWarning(Warning):
@@ -203,6 +205,9 @@ class Runtime:
             self.cache_dir = get_cache_dir(self.project_dir)
         self.config = AnsibleConfig()
 
+        # Add the sys.path to the collection paths if not isolated
+        self._add_sys_path_to_collection_paths()
+
         if not self.version_in_range(lower=min_required_version):
             msg = f"Found incompatible version of ansible runtime {self.version}, instead of {min_required_version} or newer."
             raise RuntimeError(msg)
@@ -230,6 +235,11 @@ class Runtime:
         # Monkey patch ansible warning in order to use warnings module.
         Display.warning = warning
 
+    def _add_sys_path_to_collection_paths(self) -> None:
+        """Add the sys.path to the collection paths."""
+        if not self.isolated and self.config.collections_scan_sys_path:
+            self.config.collections_paths.extend(sys.path)  # pylint: disable=E1101
+
     def load_collections(self) -> None:
         """Load collection data."""
         self.collections = OrderedDict()
@@ -553,19 +563,6 @@ class Runtime:
                     _logger.error(result.stderr)
                     raise AnsibleCommandError(result)
 
-    def search_galaxy_paths(self, search_dir: Path, depth: int = 0) -> list[str]:
-        """Search for galaxy paths (only one level deep)."""
-        galaxy_paths: list[str] = []
-        for file in os.listdir(search_dir):
-            file_path = Path(file)
-            if file_path.is_dir() and depth < 1:
-                galaxy_paths.extend(self.search_galaxy_paths(file_path, 1))
-            elif fnmatch.fnmatch(file, "galaxy.yml"):
-                galaxy_paths.append(str(search_dir / file))
-        if depth == 0 and not galaxy_paths:
-            return ["galaxy.yml"]
-        return galaxy_paths
-
     def prepare_environment(  # noqa: C901
         self,
         required_collections: dict[str, str] | None = None,
@@ -587,7 +584,13 @@ class Runtime:
         for req_file in REQUIREMENT_LOCATIONS:
             self.install_requirements(Path(req_file), retry=retry, offline=offline)
 
-        for gpath in self.search_galaxy_paths(self.project_dir):
+        self._prepare_ansible_paths()
+
+        if not install_local:
+            return
+
+        for gpath in search_galaxy_paths(self.project_dir):
+            # processing all found galaxy.yml files
             galaxy_path = Path(gpath)
             if galaxy_path.exists():
                 data = yaml_from_file(galaxy_path)
@@ -603,59 +606,54 @@ class Runtime:
                             destination=destination,
                         )
 
-            if self.cache_dir:
-                destination = self.cache_dir / "collections"
-            for name, min_version in required_collections.items():
-                self.install_collection(
-                    f"{name}:>={min_version}",
-                    destination=destination,
+        if self.cache_dir:
+            destination = self.cache_dir / "collections"
+        for name, min_version in required_collections.items():
+            self.install_collection(
+                f"{name}:>={min_version}",
+                destination=destination,
+            )
+
+        if Path("galaxy.yml").exists():
+            if destination:
+                # while function can return None, that would not break the logic
+                colpath = Path(
+                    f"{destination}/ansible_collections/{colpath_from_path(Path.cwd())}",
                 )
-
-            self._prepare_ansible_paths()
-
-            if not install_local:
-                return
-
-            if galaxy_path.exists():
-                if destination:
-                    # while function can return None, that would not break the logic
-                    colpath = Path(
-                        f"{destination}/ansible_collections/{colpath_from_path(Path.cwd())}",
-                    )
-                    if colpath.is_symlink():
-                        if os.path.realpath(colpath) == Path.cwd():
-                            _logger.warning(
-                                "Found symlinked collection, skipping its installation.",
-                            )
-                            return
+                if colpath.is_symlink():
+                    if os.path.realpath(colpath) == Path.cwd():
                         _logger.warning(
-                            "Collection is symlinked, but not pointing to %s directory, so we will remove it.",
-                            Path.cwd(),
+                            "Found symlinked collection, skipping its installation.",
                         )
-                        colpath.unlink()
+                        return
+                    _logger.warning(
+                        "Collection is symlinked, but not pointing to %s directory, so we will remove it.",
+                        Path.cwd(),
+                    )
+                    colpath.unlink()
 
-                # molecule scenario within a collection
-                self.install_collection_from_disk(
-                    galaxy_path.parent,
-                    destination=destination,
-                )
-            elif (
-                Path().resolve().parent.name == "roles"
-                and Path("../../galaxy.yml").exists()
-            ):
-                # molecule scenario located within roles/<role-name>/molecule inside
-                # a collection
-                self.install_collection_from_disk(
-                    Path("../.."),
-                    destination=destination,
-                )
-            else:
-                # no collection, try to recognize and install a standalone role
-                self._install_galaxy_role(
-                    self.project_dir,
-                    role_name_check=role_name_check,
-                    ignore_errors=True,
-                )
+            # molecule scenario within a collection
+            self.install_collection_from_disk(
+                galaxy_path.parent,
+                destination=destination,
+            )
+        elif (
+            Path().resolve().parent.name == "roles"
+            and Path("../../galaxy.yml").exists()
+        ):
+            # molecule scenario located within roles/<role-name>/molecule inside
+            # a collection
+            self.install_collection_from_disk(
+                Path("../.."),
+                destination=destination,
+            )
+        else:
+            # no collection, try to recognize and install a standalone role
+            self._install_galaxy_role(
+                self.project_dir,
+                role_name_check=role_name_check,
+                ignore_errors=True,
+            )
         # reload collections
         self.load_collections()
 
@@ -802,13 +800,17 @@ class Runtime:
         """
         yaml = None
         galaxy_info = {}
-        meta_filename = Path(project_dir) / "meta" / "main.yml"
 
-        if not meta_filename.exists():
+        for meta_main in META_MAIN:
+            meta_filename = Path(project_dir) / meta_main
+
+            if meta_filename.exists():
+                break
+        else:
             if ignore_errors:
                 return
-        else:
-            yaml = yaml_from_file(meta_filename)
+
+        yaml = yaml_from_file(meta_filename)
 
         if yaml and "galaxy_info" in yaml:
             galaxy_info = yaml["galaxy_info"]
@@ -900,3 +902,17 @@ def _get_galaxy_role_ns(galaxy_infos: dict[str, Any]) -> str:
 def _get_galaxy_role_name(galaxy_infos: dict[str, Any]) -> str:
     """Compute role name from meta/main.yml."""
     return galaxy_infos.get("role_name", "")
+
+
+def search_galaxy_paths(search_dir: Path) -> list[str]:
+    """Search for galaxy paths (only one level deep)."""
+    galaxy_paths: list[str] = []
+    for file in [".", *os.listdir(search_dir)]:
+        # We ignore any folders that are not valid namespaces, just like
+        # ansible galaxy does at this moment.
+        if file != "." and not namespace_re.match(file):
+            continue
+        file_path = search_dir / file / "galaxy.yml"
+        if file_path.is_file():
+            galaxy_paths.append(str(file_path))
+    return galaxy_paths
